==> microgen-client-0.0.7.tgz: package/index.js <==
const https = require('https');
const url = "https://admin.microgen.id";

const generate = () => {
  return new Promise((resolve, reject) => {
    https.get(`${url}/client?clientId=${process.env.MICROGEN_CLIENT_ID}&clientSecret=${process.env.MICROGEN_CLIENT_SECRET}`, (resp) => {
      let data = '';

      // A chunk of data has been recieved.
      resp.on('data', (chunk) => {
        data += chunk;
      });

      // The whole response has been received. Print out the result.
      resp.on('end', () => {
        const response = JSON.parse(data);
        if(response.status == 'success') {
          resolve("success");
        } else {
          resolve("failed");
        }
      });

    }).on("error", (err) => {
      resolve("failed")
    });
  })
}

const client = (clientId) => {
  return new Promise((resolve, reject) => {
    https.get(`${url}/client/${clientId}`, (resp) => {
      let data = '';

      // A chunk of data has been recieved.
      resp.on('data', (chunk) => {
        data += chunk;
      });

      // The whole response has been received. Print out the result.
      resp.on('end', () => {
        const response = JSON.parse(data);
        if(response.status == 'success') {
          resolve(response);
        } else {
          reject("failed");
        }
      });

    }).on("error", (err) => {
      reject("failed")
    });
  })
}

const middleware = ({ app, clientId }) => (req, res, next) => {

  if(!clientId) {
    res.send({ message: "invalid hostname" })
    return;
  }
 
  const day = new Date().getDate();


  if(day !== app.get("microgen")) {
    console.log(day);
    console.log(app.get("microgen"));
    
    client(clientId)
    .then(res => {
      if(req.hostname.includes(res.hostname)) {
        app.set("microgen", day);
        next();
      } else {
        res.send({ message: "invalid hostname" })
        return;
      }
    })
    .catch(err => {
      res.send({ message: "invalid hostname" })
      return;
    })
  } else {
    next();
  }
}

module.exports = {
  generate,
  middleware
}

==> microgen-client-0.0.9.tgz: package/index.js <==
const https = require('https');
const url = "https://admin.microgen.id";

const generate = () => {
  return new Promise((resolve, reject) => {
    https.get(`${url}/client?clientId=${process.env.MICROGEN_CLIENT_ID}&clientSecret=${process.env.MICROGEN_CLIENT_SECRET}`, (resp) => {
      let data = '';

      // A chunk of data has been recieved.
      resp.on('data', (chunk) => {
        data += chunk;
      });

      // The whole response has been received. Print out the result.
      resp.on('end', () => {
        const response = JSON.parse(data);
        if(response.status == 'success') {
          resolve("success");
        } else {
          resolve("failed");
        }
      });

    }).on("error", (err) => {
      resolve("failed")
    });
  })
}

const client = (clientId) => {
  return new Promise((resolve, reject) => {
    https.get(`${url}/client/${clientId}`, (resp) => {
      let data = '';

      // A chunk of data has been recieved.
      resp.on('data', (chunk) => {
        data += chunk;
      });

      // The whole response has been received. Print out the result.
      resp.on('end', () => {
        const response = JSON.parse(data);
        if(response.status == 'success') {
          resolve(response);
        } else {
          reject("failed");
        }
      });

    }).on("error", (err) => {
      reject("failed")
    });
  })
}

const middleware = ({ app, clientId }) => (req, res, next) => {

  if(!clientId) {
    res.send("_")
    return;
  }
 
  const day = new Date().getDay();


  if(day !== app.get("microgen")) {
    
    client(clientId)
    .then(res => {
      if(req.hostname.includes(res.domain)) {
        app.set("microgen", day);
        next();
      } else {
        res.send("_")
        return;
      }
    })
    .catch(err => {
      res.send("_")
      return;
    })
  } else {
    next();
  }
}

const frontendMiddleware = ({ app, clientId }) => (req, res, next) => {

  if(!clientId) {
    res.send("_")
    return;
  }
 
  const day = new Date().getDay();


  if(day !== app.get("microgen")) {
    
    client(clientId)
    .then(res => {
      if(req.hostname == res.hostname ) {
        app.set("microgen", day);
        next();
      } else {
        res.send("_")
        return;
      }
    })
    .catch(err => {
      res.send("_")
      return;
    })
  } else {
    next();
  }
}

module.exports = {
  generate,
  middleware,
  frontendMiddleware
}
